How to install LinkML — linkml documentation

# How to install LinkML

There are a variety of ways to install LinkML.

Note that for some purposes you may not even need to install LinkML itself. Many operations can be automated via GitHub actions.

## Install Python

Python 3.7 or higher is needed to use the LinkML toolchain

Get the latest version of Python at https://www.python.org/downloads/ or with your operating system’s package manager.

## Install LinkML

    pip install linkml